
TODO_82_25_90_46: When there is already existing symlinks (e.g. pointing to some old `venv`), bootstrap does not override them (by `ln -sn`).

*   If `ln -snf` is used, it overwrites regular target file (not so save).
*   If `ln -sn` is used, it leaves already existing links.

Maybe just use `ln -snf`?
*   If file was there, it must have been under revision control anyway.
*   If it was a link, overwrite makes sense.

TODO: Rethink deployment:
*   `deploy_config_files_conf.bash` deploys as file content (not symlink) and it does not want to override.
*   `deploy_resource_files_conf.bash` deploys as symlink and it should force it.
In short, override or not has to be conditional.

BUT! `ln -snf` does not work if it is already same file (if symlink was already there).
